"use strict";

/*
  Returns the config options for `gatsby-source-netlify-cms`
  the NelityCMS config passed. 🚀
*/
const createPluginOptions = (config = {
  collections: []
}, {
  widgetTypeDefs = {}
} = {}) => {
  const pascalCase = str => {
    return ` ${str}`.replace(/[^a-zA-Z0-9]+(.)/g, (m, chr) => chr.toUpperCase());
  };

  let types = {};
  config.collections.forEach(collection => {
    if (collection.name) {
      if (collection.folder) {
        const name = `${collection.name}`;
        types[name] = {
          type: pascalCase(name),
          contentPath: collection.folder,
          isNode: true,
          infer: false
        };
      } else {
        collection.files.forEach(file => {
          const name = `${collection.name}_${file.name}`;
          types[name] = {
            type: pascalCase(name),
            isNode: true,
            infer: false
          };
        });
      }
    }
  });
  return {
    config,
    widgetTypeDefs,
    types
  };
};

module.exports = createPluginOptions;